@@ -15,12 +15,13 @@
 
 extern crate libc;
 
-use std::fmt::Debug;
-use std::mem;
-use std::collections::HashMap;
-use std::fmt::Formatter;
-use std::fmt::Error as FormatterError;
-use std::ops::{Index, IndexMut};
+use std::{
+    collections::HashMap,
+    fmt::{Debug, Error as FormatterError, Formatter},
+    mem,
+    ops::{Index, IndexMut},
+    pin::Pin,
+};
 use rand::{rngs::SmallRng, Rng, SeedableRng};
 
 use crate::{
@@ -147,7 +148,7 @@ impl<E: UserDefinedError, I: InstructionMeter> PartialEq for JitProgram<E, I> {
 }
 
 impl<E: UserDefinedError, I: InstructionMeter> JitProgram<E, I> {
-    pub fn new(executable: &Executable<E, I>) -> Result<Self, EbpfError<E>> {
+    pub fn new(executable: &Pin<Box<Executable<E, I>>>) -> Result<Self, EbpfError<E>> {
         let program = executable.get_text_bytes().1;
         let mut jit = JitCompiler::new::<E>(program, executable.get_config())?;
         jit.compile::<E, I>(executable)?;
@@ -979,7 +980,7 @@ impl JitCompiler {
     }
 
     fn compile<E: UserDefinedError, I: InstructionMeter>(&mut self,
-            executable: &Executable<E, I>) -> Result<(), EbpfError<E>> {
+            executable: &Pin<Box<Executable<E, I>>>) -> Result<(), EbpfError<E>> {
         let (program_vm_addr, program) = executable.get_text_bytes();
         self.program_vm_addr = program_vm_addr;
 
@@ -1300,7 +1301,7 @@ impl JitCompiler {
                         // Workaround for unresolved symbols in ELF: Report error at runtime instead of compiletime
                         emit_rust_call(self, Executable::<E, I>::report_unresolved_symbol as *const _, &[
                             Argument { index: 2, value: Value::Constant64(self.pc as i64, false) },
-                            Argument { index: 1, value: Value::Constant64(executable as *const _ as i64, false) },
+                            Argument { index: 1, value: Value::Constant64(&*executable.as_ref() as *const _ as i64, false) },
                             Argument { index: 0, value: Value::RegisterIndirect(RBP, slot_on_environment_stack(self, EnvironmentStackSlot::OptRetValPtr), false) },
                         ], None, true)?;
                         X86Instruction::load_immediate(OperandSize::S64, R11, self.pc as i64).emit(self)?;
@@ -1442,7 +1443,7 @@ impl JitCompiler {
                 emit_alu(self, OperandSize::S64, 0x09, RCX, R11, 0, None)?; // gapped_offset = above_gap | below_gap;
             }
             X86Instruction::lea(OperandSize::S64, R11, RCX, Some(X86IndirectAccess::Offset(*len))).emit(self)?; // RCX = R11 + len;
-            X86Instruction::cmp(OperandSize::S8, RCX, RAX, Some(X86IndirectAccess::Offset(16))).emit(self)?; // region.len < R11 + len
+            X86Instruction::cmp(OperandSize::S64, RCX, RAX, Some(X86IndirectAccess::Offset(16))).emit(self)?; // region.len < R11 + len
             emit_jcc(self, 0x82, TARGET_PC_MEMORY_ACCESS_VIOLATION + target_offset)?;
             emit_alu(self, OperandSize::S64, 0x03, R11, RAX, 0, Some(X86IndirectAccess::Offset(0)))?; // R11 += region.host_addr;
             if self.config.enable_stack_frame_gaps {
@@ -1644,4 +1645,4 @@ impl JitCompiler {
             *offset = unsafe { (self.result.text_section.as_ptr() as *const u8).add(*offset as usize) } as u64;
         }
     }
-}
\ No newline at end of file
+}
