@@ -27,6 +27,7 @@ use log::debug;
 use std::{
     collections::{BTreeMap, HashMap},
     fmt::Debug,
+    pin::Pin,
     u32,
 };
 
@@ -194,6 +195,8 @@ pub struct Config {
     pub reject_unresolved_syscalls: bool,
     /// Reject ELF files containing section headers where sh_addr != sh_offset
     pub reject_section_virtual_address_file_offset_mismatch: bool,
+    /// Reject ELF files containing writable data sections
+    pub reject_all_writable_sections: bool,
     /// Ratio of random no-ops per instruction in JIT (0.0 = OFF)
     pub noop_instruction_ratio: f64,
     /// Enable disinfection of immediate values and offsets provided by the user in JIT
@@ -217,6 +220,7 @@ impl Default for Config {
             enable_symbol_and_section_labels: false,
             reject_unresolved_syscalls: false,
             reject_section_virtual_address_file_offset_mismatch: false,
+            reject_all_writable_sections: false,
             noop_instruction_ratio: 1.0 / 256.0,
             sanitize_user_provided_values: true,
             encrypt_environment_registers: true,
@@ -237,13 +241,12 @@ impl<E: UserDefinedError, I: 'static + InstructionMeter> Executable<E, I> {
         verifier: Option<Verifier>,
         config: Config,
         syscall_registry: SyscallRegistry,
-    ) -> Result<Self, EbpfError<E>> {
-        let ebpf_elf = Executable::load(config, elf_bytes, syscall_registry)?;
-        let text_bytes = ebpf_elf.get_text_bytes().1;
+    ) -> Result<Pin<Box<Self>>, EbpfError<E>> {
+        let executable = Executable::load(config, elf_bytes, syscall_registry)?;
         if let Some(verifier) = verifier {
-            verifier(text_bytes, &config)?;
+            verifier(executable.get_text_bytes().1, &config)?;
         }
-        Ok(ebpf_elf)
+        Ok(Pin::new(Box::new(executable)))
     }
     /// Creates a verified executable from machine code
     pub fn from_text_bytes(
@@ -252,16 +255,16 @@ impl<E: UserDefinedError, I: 'static + InstructionMeter> Executable<E, I> {
         config: Config,
         syscall_registry: SyscallRegistry,
         bpf_functions: BTreeMap<u32, (usize, String)>,
-    ) -> Result<Self, EbpfError<E>> {
+    ) -> Result<Pin<Box<Self>>, EbpfError<E>> {
         if let Some(verifier) = verifier {
             verifier(text_bytes, &config).map_err(EbpfError::VerifierError)?;
         }
-        Ok(Executable::new_from_text_bytes(
+        Ok(Pin::new(Box::new(Executable::new_from_text_bytes(
             config,
             text_bytes,
             syscall_registry,
             bpf_functions,
-        ))
+        ))))
     }
 }
 
@@ -477,7 +480,7 @@ impl<'a, E: UserDefinedError, I: InstructionMeter> EbpfVm<'a, E, I> {
     /// let mut vm = EbpfVm::<UserError, TestInstructionMeter>::new(&executable, &mut [], &mut []).unwrap();
     /// ```
     pub fn new(
-        executable: &'a Executable<E, I>,
+        executable: &'a Pin<Box<Executable<E, I>>>,
         heap_region: &mut [u8],
         input_region: &mut [u8],
     ) -> Result<EbpfVm<'a, E, I>, EbpfError<E>> {
